==> manaplus-1.1.3.20.tar.bz2: manaplus/src/net/tmwa/adminhandler.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef NET_TA_ADMINHANDLER_H
#define NET_TA_ADMINHANDLER_H

#include "net/adminhandler.h"
#include "net/net.h"

#include "net/tmwa/messagehandler.h"

#ifdef __GNUC__
#define _UNUSED_  __attribute__ ((unused))
#else
#define _UNUSED_
#endif

namespace TmwAthena
{

class AdminHandler : public MessageHandler, public Net::AdminHandler
{
    public:
        AdminHandler();

        void handleMessage(Net::MessageIn &msg);

        void announce(const std::string &text);

        void localAnnounce(const std::string &text);

        void hide(bool hide);

        void kick(int playerId);

        void kick(const std::string &name);

        void ban(int playerId);

        void ban(const std::string &name);

        void unban(int playerId);

        void unban(const std::string &name);

        void mute(int playerId, int type, int limit);
};

} // namespace TmwAthena

#endif // NET_TA_ADMINHANDLER_H

==> manaplus-1.1.6.26.tar.bz2: manaplus/src/net/tmwa/adminhandler.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef NET_TA_ADMINHANDLER_H
#define NET_TA_ADMINHANDLER_H

#include "net/adminhandler.h"
#include "net/net.h"

#include "net/ea/adminhandler.h"

#include "net/tmwa/messagehandler.h"

#ifdef __GNUC__
#define _UNUSED_  __attribute__ ((unused))
#else
#define _UNUSED_
#endif

namespace TmwAthena
{

class AdminHandler : public MessageHandler, public Ea::AdminHandler
{
    public:
        AdminHandler();

        void handleMessage(Net::MessageIn &msg);

        void announce(const std::string &text);

        void localAnnounce(const std::string &text);

        void hide(bool hide);

        void kick(int playerId);
};

} // namespace TmwAthena

#endif // NET_TA_ADMINHANDLER_H
